@@ -1,11 +1,13 @@
 import os
 import time
 import tkinter as tk
+from decimal import Decimal
 from pathlib import Path
 from tkinter import filedialog as fd
 from tkinter import simpledialog as sd
 from tkinter.colorchooser import askcolor
 
+import numpy as np
 import pynput
 from PIL import Image, ImageTk
 
@@ -118,6 +120,9 @@ class MainApplication(tk.Frame):
         self.normvaluemenu = tk.StringVar()
         self.normvaluemenu.set("max")
 
+        self.info = tk.BooleanVar()
+        self.info.set(False)
+
         self.errlimval = tk.StringVar()
         self.errlimval.set("absolute")
 
@@ -340,8 +345,6 @@ class MainApplication(tk.Frame):
             label=self.text.resetmarkers[self.lang], command=self.reset_markers
         )
 
-        self.normmenu.add_separator()
-
         self.normalizemenu = tk.Menu(self.menubar, tearoff=False)
         self.normalizemenu.add_checkbutton(
             label=self.text.normalize[self.lang],
@@ -371,22 +374,7 @@ class MainApplication(tk.Frame):
             label=self.text.choosenormalization[self.lang], menu=self.normalize_cascade
         )
 
-        self.normmenu.add_cascade(
-            label=self.text.normalization[self.lang], menu=self.normalizemenu
-        )
-        self.normmenu.add_checkbutton(
-            label=self.text.errorbars[self.lang],
-            command=self.show_errorbars,
-            variable=self.errorbars,
-        )
-        self.normmenu.add_checkbutton(
-            label=self.text.zoom[self.lang], command=self.zoomgraph, variable=self.zoom,
-        )
-
-        self.normmenu.add_checkbutton(
-            label=self.text.half[self.lang], command=self.halfgraph, variable=self.half,
-        )
-        self.normmenu.add_separator()
+        self.calcparammenu = tk.Menu(self.menubar, tearoff=False)
 
         self.parammenu = tk.Menu(self.menubar, tearoff=False)
         self.parammenu.add_checkbutton(
@@ -400,17 +388,17 @@ class MainApplication(tk.Frame):
             variable=self.tablevar,
         )
 
-        self.normmenu.add_cascade(
+        self.calcparammenu.add_cascade(
             label=self.text.calcparams[self.lang], menu=self.parammenu
         )
 
-        self.normmenu.add_checkbutton(
+        self.calcparammenu.add_checkbutton(
             label=self.text.caxcorrection[self.lang],
             command=self.correct_caxdev,
             variable=self.caxcorrection,
         )
-        self.normmenu.add_separator()
-        self.normmenu.add_checkbutton(
+        self.calcparammenu.add_separator()
+        self.calcparammenu.add_checkbutton(
             label=self.text.differenceplot[self.lang],
             command=self.differenceplot,
             variable=self.diffplot,
@@ -430,7 +418,7 @@ class MainApplication(tk.Frame):
             command=self.changegamma,
         )
 
-        self.normmenu.add_cascade(
+        self.calcparammenu.add_cascade(
             label=self.text.gammamenu[self.lang], menu=self.gammamenu
         )
 
@@ -475,13 +463,13 @@ class MainApplication(tk.Frame):
             label=self.text.changeerr[self.lang], menu=self.errlimvalmenu
         )
 
-        self.normmenu.add_cascade(
+        self.calcparammenu.add_cascade(
             label=Text().errlimmenu[self.lang], menu=self.errlimmenu
         )
 
-        self.normmenu.entryconfig(13, state=tk.DISABLED)
-        #self.normmenu.entryconfig(14, state=tk.DISABLED)
-        self.normmenu.entryconfig(15, state=tk.DISABLED)
+        self.calcparammenu.entryconfig(3, state=tk.DISABLED)
+        self.calcparammenu.entryconfig(4, state=tk.DISABLED)
+        self.calcparammenu.entryconfig(5, state=tk.DISABLED)
 
         self.menubar.add_command(label=self.text.about[self.lang], command=self.about)
 
@@ -698,9 +686,9 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(4, state=tk.NORMAL)
         self.filemenu.entryconfig(5, state=tk.NORMAL)
         if len(self.filenames) > 2:
-            self.normmenu.entryconfig(13, state=tk.DISABLED)
-            #self.normmenu.entryconfig(14, state=tk.DISABLED)
-            self.normmenu.entryconfig(15, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(3, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(4, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(5, state=tk.DISABLED)
         self.saved = False
 
         return
@@ -762,9 +750,9 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(4, state=tk.NORMAL)
         self.filemenu.entryconfig(5, state=tk.NORMAL)
         if len(self.filenames) > 2:
-            self.normmenu.entryconfig(13, state=tk.DISABLED)
-            #self.normmenu.entryconfig(14, state=tk.DISABLED)
-            self.normmenu.entryconfig(15, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(3, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(4, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(5, state=tk.DISABLED)
         self.saved = False
 
     def close_file(self, event=None):
@@ -778,11 +766,14 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(5, state=tk.DISABLED)
         self.addmeasuremenu.entryconfig(0, state=tk.NORMAL)
         self.addmeasuremenu.entryconfig(1, state=tk.NORMAL)
-        self.normmenu.entryconfig(13, state=tk.DISABLED)
-        #self.normmenu.entryconfig(14, state=tk.DISABLED)
-        self.normmenu.entryconfig(15, state=tk.DISABLED)
+        self.calcparammenu.entryconfig(3, state=tk.DISABLED)
+        self.calcparammenu.entryconfig(4, state=tk.DISABLED)
+        self.calcparammenu.entryconfig(5, state=tk.DISABLED)
         self.parammenu.entryconfig(0, state=tk.NORMAL)
-        self.menubar.delete(4, 5)
+        [self.menubar.delete(4) for i in range(3)]
+        [self.viewmenu.delete(3) for i in range(6)]
+        self.menubar.add_command(label=self.text.about[self.lang], command=self.about)
+
         self.filenames = []
         try:
             self.canvas.itemconfig(self.image_on_canvas, image=None)
@@ -940,9 +931,9 @@ class MainApplication(tk.Frame):
         if len(self.filenames) == 2:
             self.diffplot.set(False)
             self.DoseFigureHandler.diffplot = False
-            self.normmenu.entryconfig(13, state=tk.DISABLED)
-            #self.normmenu.entryconfig(14, state=tk.DISABLED)
-            self.normmenu.entryconfig(15, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(3, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(4, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(5, state=tk.DISABLED)
 
         if self.filenames[-1][0].endswith(".mcc") == True:
             self.filenames.pop(-1)
@@ -981,9 +972,9 @@ class MainApplication(tk.Frame):
 
         self.DoseFigureHandler.diffplot = self.diffplot.get()
         if self.diffplot.get() == True:
-            self.normmenu.entryconfig(14, state=tk.NORMAL)
+            self.calcparammenu.entryconfig(4, state=tk.NORMAL)
         else:
-            #self.normmenu.entryconfig(14, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(4, state=tk.DISABLED)
             pass
         self.refresh()
 
@@ -1126,30 +1117,64 @@ class MainApplication(tk.Frame):
         self.parent.bind("<Down>", lambda boolean: self.change_order(False))
 
         if len(self.DoseFigureHandler.plots) >= 2:
-            self.normmenu.entryconfig(13, state=tk.DISABLED)
-            #self.normmenu.entryconfig(14, state=tk.DISABLED)
-            self.normmenu.entryconfig(15, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(3, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(4, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(5, state=tk.DISABLED)
 
         if len(self.DoseFigureHandler.plots) == 2:
-            self.normmenu.entryconfig(13, state=tk.NORMAL)
-            self.normmenu.entryconfig(14, state=tk.NORMAL)
-            self.normmenu.entryconfig(15, state=tk.NORMAL)
+            self.calcparammenu.entryconfig(3, state=tk.NORMAL)
+            self.calcparammenu.entryconfig(4, state=tk.NORMAL)
+            self.calcparammenu.entryconfig(5, state=tk.NORMAL)
 
         if len(self.DoseFigureHandler.plots) > 5:
             self.parammenu.entryconfig(0, state=tk.DISABLED)
 
         if self.direction == "Z":
             self.addmeasuremenu.entryconfig(1, state=tk.DISABLED)
-            self.normmenu.entryconfig(8, state=tk.DISABLED)
-            self.normmenu.entryconfig(11, state=tk.DISABLED)
+            self.viewmenu.entryconfig(7, state=tk.DISABLED)
+            self.calcparammenu.entryconfig(1, state=tk.DISABLED)
         else:
             self.addmeasuremenu.entryconfig(0, state=tk.DISABLED)
-            self.normmenu.entryconfig(8, state=tk.NORMAL)
-            self.normmenu.entryconfig(11, state=tk.NORMAL)
+            self.viewmenu.entryconfig(7, state=tk.NORMAL)
+            self.calcparammenu.entryconfig(1, state=tk.NORMAL)
 
         if self.menuflag == False:
+
+            self.menubar.delete(3)
             self.menubar.add_cascade(label=self.text.add[self.lang], menu=self.addmenu)
-            self.menubar.add_cascade(label="Graph", menu=self.normmenu)
+            self.menubar.add_cascade(label="Layout", menu=self.normmenu)
+
+            self.viewmenu.add_separator()
+            self.viewmenu.add_cascade(
+                label=self.text.normalization[self.lang], menu=self.normalizemenu
+            )
+            self.viewmenu.add_checkbutton(
+                label=self.text.errorbars[self.lang],
+                command=self.show_errorbars,
+                variable=self.errorbars,
+            )
+            self.viewmenu.add_checkbutton(
+                label=self.text.zoom[self.lang],
+                command=self.zoomgraph,
+                variable=self.zoom,
+            )
+
+            self.viewmenu.add_checkbutton(
+                label=self.text.half[self.lang],
+                command=self.halfgraph,
+                variable=self.half,
+            )
+            self.viewmenu.add_checkbutton(
+                label=self.text.graphinfo[self.lang], variable=self.info
+            )
+
+            self.menubar.add_cascade(
+                label=self.text.parameters[self.lang], menu=self.calcparammenu
+            )
+            self.menubar.add_command(
+                label=self.text.about[self.lang], command=self.about
+            )
+
             self.menuflag = True
         self.image_on_canvas = self.canvas.create_image(
             self.winfo_width() // 2,
@@ -1182,7 +1207,7 @@ class MainApplication(tk.Frame):
                 (0.023 + normdiff + 0.042 * i) * self.canvas.image.height() * factor,
                 0.988 * self.canvas.image.width(),
                 (0.065 + normdiff + 0.042 * i) * self.canvas.image.height() * factor,
-                fill="red",
+                fill="",
                 outline="",
                 tags="rename",
             )
@@ -1372,6 +1397,107 @@ class MainApplication(tk.Frame):
             self.show_preview()
         return
 
+    def show_graph_info(self, x, y):
+
+        try:
+            self.canvas.delete(self.infobox)
+            self.canvas.delete(self.infobox_border)
+        except Exception:
+            pass
+
+        self.DoseFigureHandler.canvas.draw()
+        dist = []
+        for plot in self.DoseFigureHandler.plots:
+
+            half = self.DoseFigureHandler.half
+            inverted_transform = self.DoseFigureHandler.ax.transData.inverted()
+            width, height = self.DoseFigureHandler.fig.canvas.get_width_height()
+            clickpoint = inverted_transform.transform(
+                (
+                    width
+                    * (
+                        -(self.canvas.winfo_width() - self.canvas.image.width()) // 2
+                        + x
+                    )
+                    / self.canvas.image.width(),
+                    abs(
+                        height
+                        * (
+                            -(self.canvas.winfo_height() - self.canvas.image.height())
+                            // 2
+                            + y
+                        )
+                        / self.canvas.image.height()
+                        - height
+                    ),
+                )
+            )
+
+            if self.norm.get() == False:
+
+                dist += [
+                    [
+                        np.sqrt(
+                            (
+                                (plot.axis[half][i] - clickpoint[0])
+                                / max(plot.axis[half])
+                            )
+                            ** 2
+                            + (
+                                (plot.dose[half][i] - clickpoint[1])
+                                / max(plot.dose[half])
+                            )
+                            ** 2
+                        )
+                        for i in range(len(plot.axis[half]))
+                    ]
+                ]
+
+            else:
+                dist += [
+                    [
+                        np.sqrt(
+                            (
+                                (plot.axis[half][i] - clickpoint[0])
+                                / max(plot.axis[half])
+                            )
+                            ** 2
+                            + (
+                                (
+                                    (plot.dose[half][i] / max(plot.dose[half]))
+                                    - clickpoint[1]
+                                )
+                                / (max(plot.dose[half]) / plot.normpoint)
+                            )
+                            ** 2
+                        )
+                        for i in range(len(plot.axis[half]))
+                    ]
+                ]
+        mins = [np.min(dist[i]) for i in range(len(dist))]
+        mins_indices = [np.argmin(dist[i]) for i in range(len(dist))]
+
+        minimum_dist, index = np.min(mins), np.argmin(mins)
+        focuspoint = [
+            self.DoseFigureHandler.plots[index].axis[half][mins_indices[index]],
+            self.DoseFigureHandler.plots[index].dose[half][mins_indices[index]],
+        ]
+        if minimum_dist < 0.05:
+
+            self.infobox = self.canvas.create_text(
+                x,
+                y - 30,
+                text=f"{focuspoint[0]:3.2f} mm\n{Decimal(focuspoint[1]):.3e} Gy",
+                justify=tk.CENTER,
+                font=("Helvetica", "16", "bold"),
+                fill=self.DoseFigureHandler.colors[index],
+            )
+
+            self.infobox_border = self.canvas.create_rectangle(
+                self.canvas.bbox(self.infobox), fill="white"
+            )
+            self.canvas.lower(self.infobox_border, self.infobox)
+
     def handle_configure(self, event=None):
 
         """
@@ -1548,6 +1674,17 @@ class MainApplication(tk.Frame):
         """
 
         if e != None:
+
+            if self.info.get() == True:
+
+                self.show_graph_info(e.x, e.y)
+            else:
+                try:
+                    self.canvas.delete(self.infobox)
+                    self.canvas.delete(self.infobox_border)
+                except Exception:
+                    pass
+
             try:
                 hoverlist = []
                 for box in self.rename_boxes:
